from pycodemon.compiler import *

def start(filename):
    prefix = ''
    if(not os.path.exists(filename)):
        print(colored(255, 15, 67, 'That Directory Does Not Exist'))
        exit()

    if(not len(filename.split('.')) > 1):
        print(colored(255, 15, 67, 'Please Specify The File Type') + colored(237, 140, 43, ('(ex. file.py)')))
        exit()
    else:
        prefix = filename.split('.')[1]

    if(prefix == 'py'):
        compilePython(filename)
    elif(prefix == 'java'):
        compileJava(filename)
    elif(prefix == 'js'):
        compileNode(filename)
    else:
        print(colored(255, 216, 66, 'This File Type Is Not Supported.'))



import sys
from pycodemon.start import start
from pycodemon.compiler import colored

def main():
    args = sys.argv[1:]
    if(len(args) == 1):
        if(args[0] == 'help'):
            print(colored(255, 216, 66, 'To Run A File In Codemon, Type') + colored(255, 236, 80, '"cm file.extension".') + colored(255, 216, 66, '\nIt will then auto-reload your program every time you press the save command two times in a row.'))
            return
        elif(args[0] == 'new'):
            print(colored(20, 170, 224, 'Enter File Directory/Name: '), end='')
            file = input()
            open(file, 'a')
            return
        start(args[0])
    else:
        print(colored(255, 16, 57, "Wrong Number Of Arguments"))

if(__name__ == '__main__'):
    main()



import os
import time
import subprocess

def colored(r, g, b, text):
    return "\033[38;2;{};{};{}m{} \033[38;2;255;255;255m".format(r, g, b, text)

def compilePython(file):
    path = ''
    if(len(file.split('/')) > 1):
        path = file.split('/')[0] + '/'

    run = 'python ' + file
    os.system('cls')
    print(colored(20, 170, 224, 'Codemon is reloading your changes...'))
    time.sleep(0.25)
    os.system('cls')
    print(colored(20, 170, 224, 'Codemon finished compiling ' + file.replace(path, '') + ' successfully!'))
    time.sleep(0.25)
    process = subprocess.Popen(run, shell=True)
    changes = os.path.getmtime(file)

    while(True):
        if changes < os.path.getmtime(file):
            startTime = time.time()
            changes = os.path.getmtime(file)
            while(startTime > time.time() - 1.25):
                if(changes < os.path.getmtime(file)):
                    process.terminate()
                    changes = os.path.getmtime(file)
                    os.system('cls')
                    print(colored(20, 170, 224, 'Codemon is reloading your changes...'))
                    time.sleep(0.25)
                    os.system('cls')
                    print(colored(20, 170, 224, 'Codemon finished compiling ' + file.replace(path, '') + ' successfully!'))
                    process = subprocess.Popen(run, shell=True)

        time.sleep(0.03)


def compileJava(file):
    run = ''
    compile = 'javac ' + file
    path = ''
    if(len(file.split('/')) > 1):
        path = file.split('/')[0] + '/'

    os.system(compile)

    if path == '':
         run = 'java ' + file.replace('.java', '').replace(path, '')
    else:
        run = 'java -cp ' + path + ' ' + file.replace('.java', '').replace(path, '')

    os.system('cls')
    print(colored(20, 170, 224, 'Codemon is reloading your changes...'))
    time.sleep(0.25)
    os.system('cls')
    print(colored(20, 170, 224, 'Codemon finished compiling ' + file.replace(path, '') + ' successfully!'))
    process = subprocess.Popen(run, shell=True)

    changes = os.path.getmtime(file)

    while(True):
        if changes < os.path.getmtime(file):
            startTime = time.time()
            changes = os.path.getmtime(file)
            while(startTime > time.time() - 1.25):
                if changes < os.path.getmtime(file):
                    process.terminate()
                    changes = os.path.getmtime(file)
                    os.system(compile)
                    os.system('cls')
                    print(colored(20, 170, 224, 'Codemon is reloading your changes...'))
                    time.sleep(0.25)
                    os.system('cls')
                    print(colored(20, 170, 224, 'Codemon finished compiling ' + file.replace(path, '') + ' successfully!'))
                    process = subprocess.Popen(run, shell=True)

        time.sleep(0.03)

def compileNode(file):
    path = ''
    if(len(file.split('/')) > 1):
        path = file.split('/')[0] + '/'

    run = 'node ' + file
    os.system('cls')
    print(colored(20, 170, 224, 'Codemon is reloading your changes...'))
    time.sleep(0.25)
    os.system('cls')
    print(colored(20, 170, 224, 'Codemon finished compiling ' + file.replace(path, '') + ' successfully!'))
    time.sleep(0.25)
    process = subprocess.Popen(run, shell=True)

    changes = os.path.getmtime(file)

    while(True):
        if changes < os.path.getmtime(file):
            startTime = time.time()
            changes = os.path.getmtime(file)
            while(startTime > time.time() - 1.25):
                if(changes < os.path.getmtime(file)):
                    process.terminate()
                    changes = os.path.getmtime(file)
                    os.system('cls')
                    print(colored(20, 170, 224, 'Codemon is reloading your changes...'))
                    time.sleep(0.25)
                    os.system('cls')
                    print(colored(20, 170, 224, 'Codemon finished compiling ' + file.replace(path, '') + ' successfully!'))
                    process = subprocess.Popen(run, shell=True)

        time.sleep(0.03)



from setuptools import setup
setup(
    name = 'pycodemon',
    url="https://github.com/techdoge/codemon",
    author="Elad Tal",
    author_email="techdoge12@gmail.com",
    version = '1.0.3',
    packages = ['pycodemon'],
    entry_points = {
        'console_scripts': ['cm = pycodemon.main:main', 'pycodemon = pycodemon.main:main']
    }
)
